pub enum EdgeMode {
Duplicate,
Wrap,
None,
}Expand description
Modes which specify how the values of out of bounds pixels are computed.
https://www.w3.org/TR/filter-effects/#element-attrdef-fegaussianblur-edgemode
Variants
Duplicate
The nearest inbounds pixel value is returned.
Wrap
The image is extended by taking the color values from the opposite of the image.
Imagine the image being tiled infinitely, with the original image at the origin.
None
Zero RGBA values are returned.